FESTIM API
==========

.. warning::

    🔨 This page is under construction. 🔨


.. automodule:: festim.boundary_conditions
    :members:
    :show-inheritance:
    :exclude-members: __weakref__
    :private-members:
    :inherited-members:


.. .. automodule:: festim.hydrogen_transport_problem
..     :members:
..     :show-inheritance:
..     :exclude-members: __weakref__
..     :private-members:
..     :inherited-members:



.. .. automodule:: festim.heat_transfer_problem
..     :members:
..     :show-inheritance:
..     :exclude-members: __weakref__
..     :inherited-members:
